@@ -126,7 +126,7 @@ class IntegerProperty(GenericProperty[int, int]):
         if isinstance(value, (int, float)):
             return int(value)
         else:
-            raise StyleValueError(f"Expected a number here, got f{value}")
+            raise StyleValueError(f"Expected a number here, got {value!r}")
 
 
 class BooleanProperty(GenericProperty[bool, bool]):
@@ -299,7 +299,7 @@ class BoxProperty:
 
         Returns:
             A ``tuple[EdgeType, Style]`` containing the string type of the box and
-                its style. Example types are "rounded", "solid", and "dashed".
+                its style. Example types are "round", "solid", and "dashed".
         """
         return obj.get_rule(self.name) or ("", self._default_color)  # type: ignore[return-value]
 
@@ -991,7 +991,7 @@ class ColorProperty:
                             self.name, context="inline", error=error, value=token
                         ),
                     )
-            parsed_color = parsed_color.with_alpha(alpha)
+            parsed_color = parsed_color.multiply_alpha(alpha)
 
             if obj.set_rule(self.name, parsed_color):
                 obj.refresh(children=True)
@@ -1172,7 +1172,7 @@ class FractionalProperty:
 
 
 class AlignProperty:
-    """Combines the horizontal and vertical alignment properties in to a single property."""
+    """Combines the horizontal and vertical alignment properties into a single property."""
 
     def __set_name__(self, owner: StylesBase, name: str) -> None:
         self.horizontal = f"{name}_horizontal"
